pub struct RawDistancePixel(/* private fields */);Expand description
A raw pixel in a 2D image
This is either a single distance value or a description of a fill; both
cases are packed into an f32 (using NaN-boxing in the latter case).
The NaN-boxing is transparent to the user; for the curious, it is
implemented by splitting the mantissa into three components:
- Bit 0 indicates the sign of the fill (1 for inside, 0 for outside)
- Bits 1-9 indicate the depth at which evaluation terminated, which is useful for certain debug visualizations
- Bits 10-17 are a fixed bit pattern, which both ensures that the value is
treated as
NaNin the[empty, depth 0]case (rather than infinity) and distinguishes fromNaNvalues generated during normal evaluation
Implementations
Sourceimpl RawDistancePixel
impl RawDistancePixel
Sourcepub fn inside(self) -> bool
pub fn inside(self) -> bool
Checks whether the pixel is inside or outside the model
Distances of exactly 0.0 and non-boxed NaN values are treated as
outside (i.e. returning false).
Sourcepub fn is_distance(self) -> bool
pub fn is_distance(self) -> bool
Checks whether this is a distance point sample
Sourcepub fn unpack(self) -> DistancePixel
pub fn unpack(self) -> DistancePixel
Unpacks into a DistancePixel