pub struct RenderConfig<'a> {
pub image_size: RenderSize,
pub world_to_model: Matrix3<f32>,
pub pixel_perfect: bool,
pub tile_sizes: Option<TileSizes>,
pub threads: Option<&'a ThreadPool>,
pub cancel: CancelToken,
}Expand description
Settings for 2D rendering
Fields
image_size: RenderSizeRender size
world_to_model: Matrix3<f32>World-to-model transform
pixel_perfect: boolRender the distance values of individual pixels
tile_sizes: Option<TileSizes>Tile sizes to use during evaluation.
If this is None, then evaluation will use
RenderHints::tile_sizes_2d to select based on evaluator type.
threads: Option<&'a ThreadPool>Thread pool to use for rendering
If this is None, then rendering is done in a single thread; otherwise,
the provided pool is used.
cancel: CancelTokenToken to cancel rendering
Implementations
Sourceimpl RenderConfig<'_>
impl RenderConfig<'_>
Sourcepub fn from_size(image_size: RenderSize) -> Self
pub fn from_size(image_size: RenderSize) -> Self
Constructs a RenderConfig with reasonable defaults
This config uses the global thread pool for rendering, has an identity transform matrix, uses render hints to choose tile sizes, and is not pixel-perfect.
To build a somewhat-customized RenderConfig, it’s typical to use this
as the base object, then replace individual fields:
let cfg = RenderConfig {
pixel_perfect: true, // override field
..RenderConfig::from_size(1024.into()) // base
};Sourcepub fn run<F: Function + RenderHints>(
&self,
shape: BoundShape<'_, F, f32>,
) -> Option<Image>
pub fn run<F: Function + RenderHints>( &self, shape: BoundShape<'_, F, f32>, ) -> Option<Image>
Render a shape in 2D using this configuration
Returns Some(Image) of pixel data on success, or None
if the render was cancelled.