VoxelRenderConfig

Struct VoxelRenderConfig 

pub struct VoxelRenderConfig<'a> {
    pub image_size: VoxelSize,
    pub world_to_model: Matrix4<f32>,
    pub tile_sizes: TileSizes,
    pub threads: Option<&'a ThreadPool>,
    pub cancel: CancelToken,
}
Settings for 3D rendering

Fields

image_size: VoxelSize

Render size

The resulting image will have the given width and height; depth sets the number of voxels to evaluate within each pixel of the image (stacked into a column going into the screen).

world_to_model: Matrix4<f32>

World-to-model transform

tile_sizes: TileSizes

Tile sizes to use during evaluation.

You’ll likely want to use RenderHints::tile_sizes_3d to select this based on evaluator type.

threads: Option<&'a ThreadPool>

Thread pool to use for rendering

If this is None, then rendering is done in a single thread; otherwise, the provided pool is used.

cancel: CancelToken

Token to cancel rendering

Implementations

Source

impl VoxelRenderConfig<'_>

pub fn run<F: Function>(&self, shape: Shape<F>) -> Option<GeometryBuffer>

Render a shape in 3D using this configuration

Returns a GeometryBuffer of pixel data, or None if rendering was cancelled.

In the resulting image, saturated pixels (i.e. pixels in the image which are fully occupied up to the camera) are represented with depth = self.image_size.depth() and a normal of [0, 0, 1].

pub fn run_with_vars<F: Function>( &self, shape: Shape<F>, vars: &ShapeVars<f32>, ) -> Option<GeometryBuffer>

Render a shape in 3D using this configuration and variables

pub fn mat(&self) -> Matrix4<f32>

Returns the combined screen-to-model transform matrix