2D and 3D rendering
To render something, build a configuration object then call its run
function, e.g. pixel::RenderConfig::run and
voxel::RenderConfig::run.
Modules
- effects
- Post-processing effects for rendered images
- pixel
- 2D bitmap rendering / rasterization
- voxel
- 3D bitmap rendering / rasterization
Structs
- BadPixel
Count - Error type for image builder
- Image
- Generic image type
Traits
- Render
Size - Trait for things that have a width and height in pixels
Type Aliases
- Color
Image - Three-channel color image