pub struct Image<P, S = ImageSize> { /* private fields */ }Expand description
Generic image type
The image is laid out in row-major order, and can be indexed either by a
usize index or a (row, column) tuple.
0 ------------> width (columns)
| |
| |
| |
V--------------
height (rows)Implementations
Sourceimpl<P: Send, S: ImageSizeLike + Sync> Image<P, S>
impl<P: Send, S: ImageSizeLike + Sync> Image<P, S>
Sourcepub fn apply_effect<F: Fn(usize, usize) -> P + Send + Sync>(
&mut self,
f: F,
threads: Option<&ThreadPool>,
)
pub fn apply_effect<F: Fn(usize, usize) -> P + Send + Sync>( &mut self, f: F, threads: Option<&ThreadPool>, )
Generates an image by computing a per-pixel function
This should be called on the output image; the closure takes (x, y)
tuples and is expected to capture one or more source images.
Sourceimpl<P, S: ImageSizeLike> Image<P, S>
impl<P, S: ImageSizeLike> Image<P, S>